<?php
/*
Plugin Name: AddAff
Plugin URI: http://tdh.me/wordpress/addaff/
Description: A global affiliate link setting with post specific links.
Version: 1.0
Author: Thord Daniel Hedengren
Author URI: http://tdh.me/
*/


/* SETTINGS PAGE
   Create the plugin settings page */

// Initiate addaff_init() in admin
add_action( 'admin_init', 'addaff_init' );

// Add the settings page function to the menu
add_action( 'admin_menu', 'addaff_add_page' );

// Whitelist the settings
function addaff_init(){
	register_setting( 'addaff_options', 'addaff_option', 'addaff_validate' );
}

// Add to the menu
function addaff_add_page() {
	add_options_page( 'AddAff Settings', 'AddAff', 'manage_options', 'addaff', 'addaff_do_page' );
}

// Create the actual settings page
function addaff_do_page() {
	?>
	<div class="wrap">
		<h2>AddAff Settings</h2>
		<p>AddAff helps you easily manage product links and add affiliate parameters to them. Most affiliate programs want you to provide a string before and sometimes after the actual product link.</p>
		<p>Example: <strong>http://aff.com/client/1234/out?=</strong><em>http://product.com/9876</em><strong>&%stringafter</strong></p>
		<p>The bold parts of the link are controlled from here, the italic part is the product link which you provide on a per post basis.</p>
		<form method="post" action="options.php">
			<?php settings_fields( 'addaff_options' ); ?>
			<?php $options = get_option( 'addaff_option' ); ?>
			<table class="form-table">
				<tr valign="top"><th scope="row">URL string to go <strong>before</strong> the product link:</th>
					<td>
						<input type="text" name="addaff_option[urlbefore]" value="<?php echo $options['urlbefore']; ?>" class="regular-text code" />
					</td>
				</tr>				
				<tr valign="top"><th scope="row">String to go <strong>after</strong> the product link:</th>
					<td>
						<input type="text" name="addaff_option[urlafter]" value="<?php echo $options['urlafter']; ?>" class="regular-text code" />
					</td>
				</tr>
			</table>
			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Changes' ) ?>" />
			</p>
		</form>
	</div>
<?php }

// Sanitize and validate input in an array.
function addaff_validate($input) {

	// Don't allow HTML in the input fields
	$input['urlbefore'] =  wp_filter_nohtml_kses($input['urlbefore']);
	$input['urlafter'] =  wp_filter_nohtml_kses($input['urlafter']);

	return $input;

}


/* META BOXES
   Add the product link meta box to posts */

// Create meta boxes
add_action( 'add_meta_boxes', 'addaff_meta' );
function addaff_meta() {
	add_meta_box( 'addaff_meta_name', __( 'Affiliate Product Link', 'addaff' ), 'addaff_meta_box', 'post', 'normal', 'core' );
}

// The meta box
function addaff_meta_box( $post ) {

	// Get values for filling in the inputs if we have them.
	$title = get_post_meta( $post->ID, '_addaff_meta_box_title', true );
	$url = get_post_meta( $post->ID, '_addaff_meta_box_url', true );
	
	// Nonce to verify intention later
	wp_nonce_field( 'save_addaff_meta_box', 'addaff_meta_box_nonce' );
	?>
	<p>
		<?php _e( 'The link title will be linked and appended to the bottom of every post when the full content is shown. This might include archive pages, depending on your theme. You can alter the particulars on <a href="options-general.php?page=addaff">the AddAff settings page</a>.', 'adaff' ); ?>
	</p>
	<p>
		<label for="event-title"><strong><?php _e( 'Affiliate Link Title:', 'addaff' ); ?></strong></label>
		<input type="text" class="widefat" id="event-title" name="_addaff_meta_box_title" value="<?php echo $title; ?>" />
	</p>
	<p>
		<label for="event-url"><strong><?php _e( 'Product URL:', 'addaff' ); ?></strong></label>
		<input type="text" class="widefat code" id="event-url" name="_addaff_meta_box_url" value="<?php echo $url; ?>" />
	</p>

	<?php
}

// Save stuff
add_action( 'save_post', 'addaff_meta_save' );
function addaff_meta_save( $id ) {

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
	
	if ( !isset( $_POST['addaff_meta_box_nonce'] ) || !wp_verify_nonce( $_POST['addaff_meta_box_nonce'], 'save_addaff_meta_box' ) ) return;
	
	if ( !current_user_can( 'edit_post' ) ) return;

	if ( isset( $_POST['_addaff_meta_box_title'] ) )
		update_post_meta( $id, '_addaff_meta_box_title', esc_attr( strip_tags( $_POST['_addaff_meta_box_title'] ) ) );
		
	if ( isset( $_POST['_addaff_meta_box_url'] ) )
		update_post_meta( $id, '_addaff_meta_box_url', esc_attr( strip_tags( $_POST['_addaff_meta_box_url'] ) ) );

}


/* OUTPUT AFFILIATE LINK
   Add the affiliate link after the_content() */

add_filter( 'the_content', 'addaff_link', 11 );
function addaff_link( $content ) {

	// Store _addaff_meta_box_title in $addaff_link_title
	$addaff_link_title = get_post_meta( get_the_ID(), '_addaff_meta_box_title', true );

	// Store _addaff_meta_box_url in $addaff_link_url
	$addaff_link_url = get_post_meta( get_the_ID(), '_addaff_meta_box_url', true );

	// Check if BOTH $addaff_link_title and $addaff_link_url has content
	if ( $addaff_link_title && $addaff_link_url != '' ) {

		// Get the addaff_option settings
		$adaff_url = get_option( 'addaff_option' );

        // Build the markup and add to $content
        $content .= '<ul id="addaff"><li class="addaff-item"><a href="';
        $content .= $adaff_url[urlbefore];
        $content .= $addaff_link_url;
        $content .= $adaff_url[urlafter];
        $content .= '">';
        $content .= $addaff_link_title;
        $content .= '</a></li></ul>';

        // Return the content
        return $content;

    }

    // Nope, both $addaff_link_title and $addaff_link_url didn't have content
    else {

    	// Return the content
    	return $content;

    }

}

?>